package com.xy.service;

import cn.hutool.core.collection.CollStreamUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.xy.dto.AlgorithmDto;
import com.xy.dto.AlgorithmGoodsDto;
import com.xy.entity.AlgorithmGoods;
import com.xy.mapper.AlgorithmGoodsMapper;
import com.xy.utils.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestBody;

import java.util.Map;
import java.util.stream.Collectors;

import static com.xy.utils.PlusBeans.toIPage;
import static com.xy.utils.PlusBeans.toPageBean;


/**
 * <p>
 * 算法平台商品库 服务实现类
 * </p>
 *
 * @author hechunping
 * @since 2023/1/13
 */
@Service
@Api(tags = "算法平台商品库")
@AllArgsConstructor
public class AlgorithmGoodsServiceImpl extends ServiceImpl<AlgorithmGoodsMapper, AlgorithmGoods> implements AlgorithmGoodsService {

    private final AlgorithmService algorithmService;

    @ApiOperation("分页查询")
    @Override
    public R<PageBean<AlgorithmGoodsDto.Vo>> page(@RequestBody AlgorithmGoodsDto.Page page) {
        //获取算法平台列表
        Map<Long, String> algorithmMap = CollStreamUtil.toMap(algorithmService.ListNameId().getData(),
                AlgorithmDto.ListNameId::getId,AlgorithmDto.ListNameId::getName);
        //查询商品分页
        PageBean pageBean = page.getPage();
        LambdaQueryWrapper<AlgorithmGoods> lambdaQueryWrapper = new MybatisPlusQuery().eqWrapper(page, AlgorithmGoods.class)
                .ge(AlgorithmGoods::getCreateTime, page.getCreateTimeStart())
                .le(AlgorithmGoods::getCreateTime, page.getCreateTimeEnd())
                .like(AlgorithmGoods::getSkuName)
                .build();
        IPage<AlgorithmGoods> iPage = page(toIPage(pageBean), lambdaQueryWrapper);
        PageBean<AlgorithmGoodsDto.Vo> dtoPageBean = toPageBean(AlgorithmGoodsDto.Vo.class, iPage);
        //设置平台名称
        dtoPageBean.setRecords(
                dtoPageBean.getRecords().stream().map(
                        item -> item.setAlgorithmName(algorithmMap.get(item.getAlgorithmId()))
                ).collect(Collectors.toList())
        );
        return R.ok(dtoPageBean);
    }

    @ApiOperation("新增")
    @Override
    public R save(@RequestBody @Validated AlgorithmGoodsDto.Save save) {
        AlgorithmGoods saveInfo = PlusBeans.copy(AlgorithmGoods.class, save);
        saveInfo.createUserTime(AuthorizeUtils.getLoginId(Long.class)).createId();
        save(saveInfo);
        return R.ok();
    }

    @ApiOperation("修改")
    @Override
    public R update(@RequestBody @Validated AlgorithmGoodsDto.Update update) {
        AlgorithmGoods updateInfo = PlusBeans.copy(AlgorithmGoods.class, update);
        updateInfo.updateUserTime(AuthorizeUtils.getLoginId(Long.class));
        updateById(updateInfo);
        return R.ok();
    }
}
