package com.xy.dto;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.xy.utils.PageBean;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.experimental.Accessors;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.time.LocalDateTime;

/**
 * <p>
 * 算法平台商品库DTO
 * </p>
 *
 * @author hechunping
 * @since 2023-01-13
 */
public class AlgorithmGoodsDto {

    @Data
    @Accessors(chain = true)
    public static class Page extends Vo{
        @ApiModelProperty(value = "分页对象", required = true)
        private PageBean page;

        @ApiModelProperty(value = "创建时间开始")
        @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
        private LocalDateTime createTimeStart;

        @ApiModelProperty(value = "创建时间结束")
        @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
        private LocalDateTime createTimeEnd;
    }

    @Data
    @Accessors(chain = true)
    public static class Save {
        @NotNull(message = "算法平台ID不能为空")
        @ApiModelProperty(value = "算法平台ID")
        private Long algorithmId;

        @ApiModelProperty(value = "条形码")
        private String barcode;

        @NotBlank(message = "算法平台商品ID不能为空")
        @ApiModelProperty(value = "算法平台商品ID")
        private String skuId;

        @NotBlank(message = "商品名称不能为空")
        @ApiModelProperty(value = "商品名称")
        private String skuName;

        @ApiModelProperty(value = "库类型")
        private String skuType;

        @ApiModelProperty(value = "商品图片")
        private String imgUrls;

        @ApiModelProperty(value = "建模商户ID")
        private Long mercId;

        @ApiModelProperty("状态;true=显示,false=隐藏")
        private Boolean status;
    }

    @Data
    @Accessors(chain = true)
    public static class Update extends Save{
        @NotNull
        @ApiModelProperty(value = "ID")
        private Long id;
    }

    @Data
    @Accessors(chain = true)
    public static class Vo {
        @ApiModelProperty("算法平台名称")
        private String algorithmName;

        @ApiModelProperty(value = "ID")
        private Long id;

        @ApiModelProperty(value = "算法平台ID")
        private Long algorithmId;

        @ApiModelProperty(value = "条形码")
        private String barcode;

        @ApiModelProperty(value = "算法平台商品ID")
        private String skuId;

        @ApiModelProperty(value = "商品名称")
        private String skuName;

        @ApiModelProperty(value = "库类型")
        private String skuType;

        @ApiModelProperty(value = "商品图片")
        private String imgUrls;

        @ApiModelProperty(value = "建模商户ID")
        private Long mercId;

        @ApiModelProperty("状态;true=显示,false=隐藏")
        private Boolean status;

        @ApiModelProperty(value = "创建人")
        private Long createUser;

        @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
        @ApiModelProperty(value = "创建时间")
        private LocalDateTime createTime;

        @ApiModelProperty(value = "更新人")
        private Long updateUser;

        @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
        @ApiModelProperty(value = "更新时间")
        private LocalDateTime updateTime;
    }

}
